// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `The Cert Ontology 1.0` vocabulary
//!
//! This module requires `ns-cert` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**|The Cert Ontology 1.0|
//! |**Prefix**|cert|
//! |**Namespace base IRI**|<https://www.w3.org/ns/auth/cert#>|
//! |**Description**|Ontology for Certificates and crypto stuff.|
//! |**Is defined by**|<http://www.w3.org/ns/auth/cert.rdf>|
//!

use crate::namespace;

namespace!(
    "https://www.w3.org/ns/auth/cert#",;
    /// ``: 
    NAMESPACE_BASE, ""
);
